use sysinfo::System;

fn main() {
    get_sys_info();
}

fn get_sys_info() {
    let bytes_per_gib: u64 = 2u64.pow(30);

    // Please note that we use "new_all" to ensure that all list of
    // components, network interfaces, disks and users are already
    // filled!
    let mut sys = System::new_all();

    // First we update all information of our `System` struct.
    sys.refresh_all();

    // Print system information:
    println!("System Name:                         {}", System::name().unwrap());
    println!("Kernel Version:                      {}", System::kernel_version().unwrap());
    println!("System OS Version:                   {}", System::os_version().unwrap());
    println!("System Hostname:                     {}", System::host_name().unwrap());

    // Print CPU information:
    println!("CPU Model:                           {}", sys.cpus()[0].brand());
    println!("CPU Architecture:                    {}", System::cpu_arch().unwrap());
    println!("Number of Cores:                     {}", sys.physical_core_count().unwrap());
    println!("Number of Cores + Threads:           {}", sys.cpus().len());

    // Print memory information:
    println!("Total Memory:                        {:.2} GB", sys.total_memory() as f64 / bytes_per_gib as f64);
}